@@ -168,6 +168,9 @@ namespace TheSeer\Autoload {
                 $config->setVariable('PHAR',
                     $input->getOption('alias')->value ? $input->getOption('alias')->value : basename($output)
                 );
+                if ($hashAlgorithm = $input->getOption('hash')->value) {
+                    $config->setPharHashAlgorithm($hashAlgorithm);
+                }
             }
 
             if ($input->getOption('cache')->value) {
@@ -281,6 +284,7 @@ Usage: phpab [switches] <directory1|file1|/path/to/composer.json> [...<directory
 
   -o, --output        Output file for generated code (default: STDOUT)
   -p, --phar          Create a phar archive (requires -o )
+      --hash          Force given hash algorithm (SHA-1, SHA-256 or SHA-512) (requires -p, conflicts with --key)
       --bzip2         Compress phar archive using bzip2 (requires -p) (bzip2 required)
       --gz            Compress phar archive using gzip (requires -p) (gzip required)
       --key           OpenSSL key file to use for signing phar archive (requires -p) (openssl required)
@@ -288,7 +292,7 @@ Usage: phpab [switches] <directory1|file1|/path/to/composer.json> [...<directory
   -c, --compat        Generate PHP 5.2 compatible code
   -s, --static        Generate a static require file
 
-  -1, --prepend       Register as first autoloader (prepend to stack, defaukt: append)
+  -1, --prepend       Register as first autoloader (prepend to stack, default: append)
   -d, --no-exception  Do not throw exception on registration problem (default: throw exception)
 
   -n, --nolower       Do not lowercase classnames for case insensitivity
@@ -390,6 +394,14 @@ EOF;
                 array( new \ezcConsoleOptionRule( $input->getOption( 'p' ) ) )
             ));
 
+            $this->outputOption = $input->registerOption( new \ezcConsoleOption(
+                '', 'hash', \ezcConsoleInput::TYPE_STRING, NULL, FALSE,
+                'Force given hash algorithm (SHA-1, SHA-256 or SHA-512) (requires -p)',
+                NULL,
+                array( new \ezcConsoleOptionRule( $input->getOption( 'p' ) ) ),
+                array( new \ezcConsoleOptionRule( $input->getOption( 'key' ) ) )
+            ));
+
             $input->registerOption( new \ezcConsoleOption(
                 'i', 'include', \ezcConsoleInput::TYPE_STRING, '*.php', TRUE,
                 'File pattern to include (default: *.php)'
@@ -455,7 +467,7 @@ EOF;
                 array( new \ezcConsoleOptionRule( $input->getOption( 'lint' ) ) )
             ));
 
-            $input->registerOption( new \ezcConsoleOption(
+            $compat = $input->registerOption( new \ezcConsoleOption(
                 'c', 'compat', \ezcConsoleInput::TYPE_NONE, NULL, FALSE,
                 'Generate PHP 5.2 compliant code'
             ));
@@ -502,7 +514,10 @@ EOF;
 
             $input->registerOption( new \ezcConsoleOption(
                 '1', 'prepend', \ezcConsoleInput::TYPE_NONE, NULL, FALSE,
-                'Prepend autoloader to stack'
+                'Prepend autoloader to stack',
+                NULL,
+                array(),
+                array( new \ezcConsoleOptionRule( $compat ) )
             ));
 
             $input->registerOption( new \ezcConsoleOption(
